.. _base:

****
Base
****

Routines on which the readers and writers for specific baseband formats
are based.

Reference/API
=============

.. automodapi:: baseband.base
.. automodapi:: baseband.base.header
.. automodapi:: baseband.base.payload
.. automodapi:: baseband.base.frame
.. automodapi:: baseband.base.base
.. automodapi:: baseband.base.offsets
.. automodapi:: baseband.base.file_info
.. automodapi:: baseband.base.encoding
   :include-all-objects:
.. automodapi:: baseband.base.utils
